@@ -1,7 +1,8 @@
+#' @export
 summary.ccc<-
 function(object,...){
 
-print(object$model)
+print(object$vc)
 cat("\n")
 cat("CCC estimated by variance compoments \n")
 print(object$ccc[1:4])
